Module shared

Module shared 

Shared data structures, utilities, and protocol definitions.

Structs

Delimited
Transport stream with JSON frames delimited by null characters.

Enums

ClientMessage
A message from the client on the control connection.
ServerMessage
A message from the server on the control connection.

Constants

CONTROL_PORT
TCP port used for control connections with the server.
MAX_FRAME_LENGTH
Maximum byte length for a JSON frame in the stream.
NETWORK_TIMEOUT
Timeout for network connections and initial protocol messages.